==> httpmime-4.0-sources.jar: org/apache/http/entity/mime/content/AbstractContentBody.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.http.entity.mime.content;

import java.util.Collections;
import java.util.Map;

import net.jcip.annotations.NotThreadSafe;

import org.apache.james.mime4j.message.Entity;
import org.apache.james.mime4j.message.SingleBody;

/**
 *
 * @since 4.0
 */
@NotThreadSafe // setParent() also SingleBody and Entity are not T-S
public abstract class AbstractContentBody extends SingleBody implements ContentBody {

    private final String mimeType;
    private final String mediaType;
    private final String subType;
    
    private Entity parent = null;

    public AbstractContentBody(final String mimeType) {
        super();
        if (mimeType == null) {
            throw new IllegalArgumentException("MIME type may not be null");
        }
        this.mimeType = mimeType;
        int i = mimeType.indexOf('/');
        if (i != -1) {
            this.mediaType = mimeType.substring(0, i);
            this.subType = mimeType.substring(i + 1);
        } else {
            this.mediaType = mimeType;
            this.subType = null;
        }
    }

    @Override
    public Entity getParent() {
        return this.parent;
    }

    @Override
    public void setParent(final Entity parent) {
        this.parent = parent;
    }

    public String getMimeType() {
        return this.mimeType;
    }
    
    public String getMediaType() {
        return this.mediaType;
    }

    public String getSubType() {
        return this.subType;
    }

    public Map<String, String> getContentTypeParameters() {
        return Collections.emptyMap();
    }

    @Override
    public void dispose() {
    }
    
}

==> httpmime-4.0.1-sources.jar: org/apache/http/entity/mime/content/AbstractContentBody.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */

package org.apache.http.entity.mime.content;

import java.util.Collections;
import java.util.Map;

import org.apache.http.annotation.NotThreadSafe;

import org.apache.james.mime4j.message.Entity;
import org.apache.james.mime4j.message.SingleBody;

/**
 *
 * @since 4.0
 */
@NotThreadSafe // setParent() also SingleBody and Entity are not T-S
public abstract class AbstractContentBody extends SingleBody implements ContentBody {

    private final String mimeType;
    private final String mediaType;
    private final String subType;
    
    private Entity parent = null;

    public AbstractContentBody(final String mimeType) {
        super();
        if (mimeType == null) {
            throw new IllegalArgumentException("MIME type may not be null");
        }
        this.mimeType = mimeType;
        int i = mimeType.indexOf('/');
        if (i != -1) {
            this.mediaType = mimeType.substring(0, i);
            this.subType = mimeType.substring(i + 1);
        } else {
            this.mediaType = mimeType;
            this.subType = null;
        }
    }

    @Override
    public Entity getParent() {
        return this.parent;
    }

    @Override
    public void setParent(final Entity parent) {
        this.parent = parent;
    }

    public String getMimeType() {
        return this.mimeType;
    }
    
    public String getMediaType() {
        return this.mediaType;
    }

    public String getSubType() {
        return this.subType;
    }

    public Map<String, String> getContentTypeParameters() {
        return Collections.emptyMap();
    }

    @Override
    public void dispose() {
    }
    
}
